@@ -338,7 +338,7 @@ void SurfaceImpl::AlphaRectangle(PRectangle rc, int cornerSize,
 	TQImage img(w, h, 32);
 
 	img.fill(convertTQRgb(fill, alphaFill));
-	img.setAlphaBuffer(TRUE);
+	img.setAlphaBuffer(true);
 
 	// Assume that "cornerSize" means outline width.
 	if (cornerSize > 0)
@@ -413,7 +413,7 @@ void SurfaceImpl::DrawTextClipped(PRectangle rc,Font &font_,int ybase,
 {
 	SetClip(rc);
 	DrawTextNoClip(rc,font_,ybase,s,len,fore,back);
-	painter -> setClipping(FALSE);
+	painter -> setClipping(false);
 }
 
 void SurfaceImpl::DrawTextTransparent(PRectangle rc,Font &font_,int ybase,
